@@ -309,7 +309,6 @@ adjust value and the ppem value at which the adjustment occurs.
 #use Parse::RecDescent;
 
 use strict;
-use Algorithm::Diff qw(sdiff);
 use Font::TTF::Font;
 use Font::TTF::Scripts::AP;
 
@@ -363,18 +362,18 @@ sub out_volt
     my ($self, %opts) = @_;
     my ($res);
     
-    $res = $self->out_volt_glyphs;
-    $res .= $self->out_volt_scripts;
-    $res .= $self->out_volt_classes;
-    $res .= $self->out_volt_lookups;
-    $res .= $self->out_volt_anchors;
-    $res .= $self->out_volt_final;
+    $res = $self->out_volt_glyphs(%opts);
+    $res .= $self->out_volt_scripts(%opts);
+    $res .= $self->out_volt_classes(%opts);
+    $res .= $self->out_volt_lookups(%opts);
+    $res .= $self->out_volt_anchors(%opts);
+    $res .= $self->out_volt_final(%opts);
     $res;
 }
 
 sub out_volt_glyphs
 {
-    my ($self) = @_;
+    my ($self, %opts) = @_;
     my ($c) = $self->{'font'}{'cmap'}->read->find_ms;
     my ($g, $res, $i, @revmap, $u);
 
@@ -395,7 +394,7 @@ sub out_volt_glyphs
             { $res .= " UNICODE $g->{'uni'}[0]"; }
         }
 
-        $type = glyph_type($g);
+        $type = glyph_type($g) || $opts{'-default_glyphtype'};
         
         $res .= " TYPE $type" if ($type);
         $res .= " COMPONENTS " . $g->{'component_num'} if ($g->{'component_num'});
@@ -1199,7 +1198,7 @@ sub parse_volt
                                 'first' => [@firsts],
                                 'second' => [@seconds],
                                 'adj' => [@adjs]});
-                        unless ($str =~ m/\GEND_ADJUST\s+/ogc)
+                        unless ($str =~ m/\G\s*END_ADJUST\s+/ogc)
                         { die "Expected END_ADJUST in LOOKUP $name, found: " . substr($str, pos($str), 20); }
                     }
 #        | 'ADJUST_SINGLE' <commit> post_single(s) 'END_ADJUST'
@@ -1311,6 +1310,8 @@ sub parse_enum
             unless ($$str =~ m/\GEND_ENUM\s+/ogc)
             { die "Expected END_ENUM, found: " . substr($$str, pos($$str), 20); }
         }
+        elsif ($$str =~ m/\GEMPTY\s+/ogc)
+        { }
         else
         { last; }
     }
@@ -1377,103 +1378,6 @@ sub parse_adjs
     return @res;
 }
 
-=head2 $fv->align_glyphs($dat)
-
-Provides one possible way to map glyph names in a new font with an existing VOLT project.
-
-Compares the list of glyphs found during L</"read_font"> (the I<new> glyph list) with the list 
-from L</"parse_volt"> in $dat (the I<old> glyph list>, returning an array that provides
-a mapping between old and new glyph IDs. The array is indexed by old glyph ID and returns the
-new glyph ID.
-
-This implementation works by C<sdiff>ing the two ordered lists of glyph C<name>s and 
-then matching them up, first by C<name> then by C<uni>.
-
-=cut
-
-sub align_glyphs
-{
-    my ($self, $data) = @_;
-    my (@map, @revmap, @old, @new, @diff, $s, $g, $u);
-
-    @new = map {$_->{'name'}} @{$self->{'glyphs'}};
-    @old = map {$_->{'name'}} @{$data->{'glyphs'}};
-    @diff = sdiff(\@old, \@new);
-
-# first find solid alignments
-    foreach $s (@diff)
-    {
-        if ($s->[0] eq 'u')
-        {
-            $map[$data->{'glyph_names'}{$s->[1]}] = $self->{'glyph_names'}{$s->[2]};
-            $revmap[$self->{'glyph_names'}{$s->[2]}] = $data->{'glyph_names'}{$s->[1]};
-        }
-    }
-
-# now deal with the rest
-    foreach $s (@diff)
-    {
-        if ($s->[0] eq '-' || $s->[0] eq 'c')
-        {
-            my ($gnum) = $data->{'glyph_names'}{$s->[1]};
-            my ($uni) = $data->{'glyphs'}[$gnum]{'uni'};
-            my ($gnew);
-    # anything with the same name not already used?
-            if ($g = $self->{'glyph_names'}{$s->[1]} and !defined $revmap[$g])
-            {
-                $map[$gnum] = $g;
-                $revmap[$g] = $gnum;
-            }
-    # anything spare with the same unicode (any unicode the same)?
-            else
-            {
-                foreach $u (@{$uni})
-                {
-                    next unless (defined $u);
-                    foreach $g (@{$self->{'glyphs'}})
-                    {
-                        if (ref $g->{'uni'} && grep {$_ == $u} @{$g->{'uni'}} && !defined $revmap[$g->{'gnum'}])
-                        {
-                            $gnew = $g->{'gnum'};
-                            last;
-                        }
-                    }
-                    if ($gnew)
-                    {
-                        $map[$gnum] = $gnew;
-                        $revmap[$gnew] = $gnum;
-                        last;
-                    }
-                }
-                unless ($gnew)
-                {
-                    print STDERR "Can't find alignment for glyph $s->[1]\n";
-                    $self->{'error'} = 1;
-            }
-            }
-    # make it a deletion (i.e. in old but not in new)
-        }
-        elsif ($s->[0] eq '+')
-        {
-            # nothing to do since only really interested in old->new mapping
-        }
-    }
-
-# deal with unaligned conflicts and simply align them
-    foreach $s (@diff)
-    {
-        if ($s->[0] eq 'c')
-        {
-            my ($gnum) = $data->{'glyph_names'}{$s->[1]};
-            my ($nnum) = $self->{'glyph_names'}{$s->[2]};
-            next if ($map[$gnum] || $revmap[$nnum]);
-            $map[$gnum] = $nnum;
-            $revmap[$nnum] = $gnum;
-        }
-    }
-    return (@map);
-}
-
 sub merge_volt
 {
     my ($self, $data, $map) = @_;
@@ -1576,6 +1480,7 @@ sub make_lookups
     foreach $c (sort keys %{$self->{'classes'}})
     {
         next if ($c =~ m/^no_/o);
+        next unless (defined $self->{'classes'}{"no_$c"});
         if ($opts->{'-force'})
         { $self->{'lookups'} = [grep {$_->{'id'} ne $c} @{$self->{'lookups'}}]; }
         else
